@@ -2,9 +2,7 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import sys
 import logging
-import six
 try:
     from json.decoder import JSONDecodeError
 except ImportError:
