@@ -5,7 +5,6 @@ SPDX-License-Identifier: MIT-0
 import re
 import logging
 from copy import deepcopy
-import six
 
 LOGGER = logging.getLogger(__name__)
 
@@ -218,7 +217,7 @@ def create_sub_node_class(cls):
 
         def __setup_list(self, v):
             if len(v) == 2:
-                if not isinstance(v[0], six.string_types):
+                if not isinstance(v[0], str):
                     return
                 self.__setup_list_sub_string(v[0])
                 if not isinstance(v[1], dict):
@@ -230,7 +229,7 @@ def create_sub_node_class(cls):
             if len(self) == 1:
                 for k, v in self.items():
                     if k == 'Fn::Sub':
-                        if isinstance(v, six.string_types):
+                        if isinstance(v, str):
                             self.__setup_list_sub_string(v)
                             self.__cache_is_valid = True
                         elif isinstance(v, list):
