@@ -7,7 +7,6 @@ import logging
 from datetime import datetime
 import importlib
 import traceback
-import six
 import cfnlint.helpers
 import cfnlint.rules.custom
 from cfnlint.decode.node import TemplateAttributeError
@@ -101,6 +100,15 @@ class CloudFormationLintRule(object):
                         self.config[key] = str(value)
                     elif self.config_definition[key]['type'] == 'integer':
                         self.config[key] = int(value)
+                    elif self.config_definition[key]['type'] == 'list':
+                        self.config[key] = []
+                        for l_value in value:
+                            if self.config_definition[key]['itemtype'] == 'boolean':
+                                self.config[key].append(cfnlint.helpers.bool_compare(l_value, True))
+                            elif self.config_definition[key]['itemtype'] == 'string':
+                                self.config[key].append(str(l_value))
+                            elif self.config_definition[key]['itemtype'] == 'integer':
+                                self.config[key].append(int(l_value))
 
     match = None
     match_resource_properties = None
@@ -394,7 +402,7 @@ class RulesCollection(object):
         for resource_name, resource_attributes in cfn.get_resources().items():
             resource_type = resource_attributes.get('Type')
             resource_properties = resource_attributes.get('Properties')
-            if isinstance(resource_type, six.string_types) and isinstance(resource_properties, dict):
+            if isinstance(resource_type, str) and isinstance(resource_properties, dict):
                 path = ['Resources', resource_name, 'Properties']
                 for rule in self.rules:
                     matches.extend(
