@@ -2,7 +2,6 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import six
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
 
@@ -21,7 +20,7 @@ class Ref(CloudFormationLintRule):
         ref_objs = cfn.search_deep_keys('Ref')
         for ref_obj in ref_objs:
             value = ref_obj[-1]
-            if not isinstance(value, (six.string_types)):
+            if not isinstance(value, (str)):
                 message = 'Ref can only be a string for {0}'
                 matches.append(
                     RuleMatch(ref_obj[:-1], message.format('/'.join(map(str, ref_obj[:-1])))))
