@@ -2,8 +2,6 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import six
-
 from cfnlint.helpers import valid_snapshot_types
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
@@ -27,7 +25,7 @@ class DeletionPolicy(CloudFormationLintRule):
             'Snapshot'
         ]
 
-        if not isinstance(key, (six.text_type, six.string_types)):
+        if not isinstance(key, (str)):
             message = 'DeletionPolicy values should be of string at {0}'
             matches.append(RuleMatch(path, message.format('/'.join(map(str, path)))))
             return matches
