@@ -2,7 +2,6 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import six
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
 
@@ -26,7 +25,7 @@ HTTPS has certificate HTTP has no certificate'
             Check Protocol Value
         """
         matches = []
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             if value.upper() not in kwargs['accepted_protocols']:
                 message = 'Protocol must be {0} is invalid at {1}'
                 matches.append(RuleMatch(path, message.format(
@@ -41,7 +40,7 @@ HTTPS has certificate HTTP has no certificate'
     def get_loadbalancer_type(self, properties):
         """ Check if type is application """
         elb_type = properties.get('Type', 'application')
-        if isinstance(elb_type, six.string_types):
+        if isinstance(elb_type, str):
             if elb_type == 'application':
                 return 'application'
             return 'network'
@@ -91,6 +90,8 @@ HTTPS has certificate HTTP has no certificate'
                 'idle_timeout.timeout_seconds',
                 'routing.http.desync_mitigation_mode',
                 'routing.http.drop_invalid_header_fields.enabled',
+                'routing.http.x_amzn_tls_version_and_cipher_suite.enabled',
+                'routing.http.xff_client_port.enabled',
                 'routing.http2.enabled',
                 'waf.fail_open.enabled'
             ],
@@ -104,7 +105,7 @@ HTTPS has certificate HTTP has no certificate'
             for item in loadbalancer_attributes:
                 key = item.get('Key')
                 value = item.get('Value')
-                if isinstance(key, six.string_types) and isinstance(value, (six.string_types, bool, six.integer_types)):
+                if isinstance(key, str) and isinstance(value, (str, bool, int)):
                     loadbalancer = self.get_loadbalancer_type(properties)
                     if loadbalancer:
                         if key not in allowed_attributes['all'] and key not in allowed_attributes[loadbalancer]:
