@@ -2,7 +2,6 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import six
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
 
@@ -21,7 +20,7 @@ class Description(CloudFormationLintRule):
         description = cfn.template.get('Description')
 
         if description:
-            if not isinstance(description, six.string_types):
+            if not isinstance(description, str):
                 message = 'Description can only be a string'
                 matches.append(RuleMatch(['Description'], message))
         return matches
